<?php
    header('Content-type: application/json');

    $appIdsWithManifest = '["nethserver-webtop5","nethserver-nextcloud","nethserver-mattermost","nethserver-roundcubemail","nethserver-firewall-base","nethserver-mail","nethserver-nethvoice14","inboundreport","queuereport","nethserver-dante","nethserver-squid","nethserver-samba","nethvoice-report"]';

    // app categories and positions
    $appCategories = [
        'nethserver-webtop5' => [ 'category' => 'user', 'position' => 10],
        'nethcti' => [ 'category' => 'user', 'position' => 20 ],
        'nethserver-nextcloud' => [ 'category' => 'user', 'position' => 30 ],
        'nethserver-mattermost' => [ 'category' => 'user', 'position' => 40 ],
        'nethserver-roundcubemail' => [ 'category' => 'user', 'position' => 50 ],
        'user-settings-page' => [ 'category' => 'user', 'position' => 90 ],

        'server-manager' => [ 'category' => 'admin', 'position' => 10 ],
        'cockpit-apps' => [ 'category' => 'admin', 'position' => 15 ],
        'nethserver-firewall-base' => [ 'category' => 'admin', 'position' => 20 ],
        'nethserver-mail' => [ 'category' => 'admin', 'position' => 30 ],
        'nethserver-nethvoice14' => [ 'category' => 'admin', 'position' => 40 ],

        'nethvoice-report' => [ 'category' => 'report', 'position' => 10 ],
        'inboundreport' => [ 'category' => 'report', 'position' => 20 ],
        'queuereport' => [ 'category' => 'report', 'position' => 30 ],
        'nethserver-dante' => [ 'category' => 'report', 'position' => 40 ],
        'nethserver-squid' => [ 'category' => 'report', 'position' => 50 ],
        'nethserver-samba' => [ 'category' => 'report', 'position' => 60 ],
    ];

    $systemApps = shell_exec('echo \'{"action":"launcher","appIds":' . $appIdsWithManifest . ',"location":{"hostname":"' . $_SERVER['SERVER_NAME'] . '", "protocol":"https:"}}\' | /usr/bin/sudo /usr/libexec/nethserver/api/system-apps/read');
    $systemAppsJson = json_decode($systemApps, true);

    if (is_null($systemAppsJson)) {
        // invalid json
        echo json_encode([]);
    } else {
        // manually added apps
        array_push($systemAppsJson, [ "id" => "cockpit-apps", "url" => "https://" . $_SERVER['SERVER_NAME'] . ":9090/nethserver#/applications" ]);
        array_push($systemAppsJson, [ "id" => "server-manager", "url" => "https://" . $_SERVER['SERVER_NAME'] . ":9090" ]);

        $nethvoiceInstalled = FALSE;

        // set category and position
        foreach ($systemAppsJson as &$app) {
            if (array_key_exists($app["id"], $appCategories)) {
                $app["category"] = $appCategories[$app["id"]]["category"];
                $app["position"] = $appCategories[$app["id"]]["position"];

                // nethvoice
                if (strcmp("nethserver-nethvoice14", $app["id"]) == 0) {
                    $nethvoiceInstalled = TRUE;

                    // check rebranding
                    $nethvoiceBrandedName = "";
                    $lines = file("/var/www/html/freepbx/wizard/scripts/custom.js");
                    foreach($lines as $line) {
                        if (strpos($line, 'BRAND_NAME') != false) {
                            preg_match("/BRAND_NAME: '(.+)',/", $line, $matches);

                            if (count($matches) == 2) {
                                $nethvoiceBrandedName = $matches[1];
                                break;
                            }
                        }
                    }

                    if (strcmp($nethvoiceBrandedName, "NethVoice") != 0) {
                        // NethVoice has been rebranded
                        $app["url"] = "https://" . $_SERVER['SERVER_NAME'] . "/" . strtolower($nethvoiceBrandedName);
                        $app["customName"] = $nethvoiceBrandedName;
                        $logoPath = "/var/www/html/freepbx/admin/brand/logo.png";
                        $logoType = pathinfo($logoPath, PATHINFO_EXTENSION);
                        $logoData = file_get_contents($logoPath);
                        $logoBase64 = 'data:image/' . $logoType . ';base64,' . base64_encode($logoData);
                        $app["customLogo"] = $logoBase64;
                    }
                }

                // user settings page
                if (strcmp("user-settings-page", $app["id"]) == 0) {
                    $alias = $app["url"];
                    $app["url"] = "https://" . $_SERVER['SERVER_NAME'] . $alias;
                }
            }
        }

        if ($nethvoiceInstalled) {
            // add CTI app as well
            $ctiApp = [ "id" => "nethcti",
                        "url" => "https://" . $_SERVER['SERVER_NAME'] . "/cti",
                        "category" => $appCategories["nethcti"]["category"],
                        "position" => $appCategories["nethcti"]["position"]
                      ];

            // check rebranding
            $ctiBrandedName = "";
            $lines = file("/usr/share/cti/scripts/custom.js");
            foreach($lines as $line) {
                if (strpos($line, 'BRAND_NAME') != false) {
                    preg_match("/BRAND_NAME: '(.+)',/", $line, $matches);

                    if (count($matches) == 2) {
                        $ctiBrandedName = $matches[1];
                        break;
                    }
                }
            }

            if (strcmp($ctiBrandedName, "NethCTI") != 0) {
                // CTI has been rebranded
                $ctiApp["customName"] = $ctiBrandedName;
                $logoPath = "/usr/share/cti/img/logo.png";
                $logoType = pathinfo($logoPath, PATHINFO_EXTENSION);
                $logoData = file_get_contents($logoPath);
                $logoBase64 = 'data:image/' . $logoType . ';base64,' . base64_encode($logoData);
                $ctiApp["customLogo"] = $logoBase64;
            }
            array_push($systemAppsJson, $ctiApp);
        }
        $systemApps = json_encode($systemAppsJson);
        echo $systemApps;
    }
